@@ -21,6 +21,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "exchange-mapi-cal-recur-utils.h"
 
 /* Reader/Writer versions */
@@ -145,6 +149,7 @@ get_mapi_pos (int32_t pos)
 
 #define cFileTimeUnitsPerSecond 10000000
 
+#if 0
 static void
 convert_recurrence_minutes_to_date (uint32_t minutes, struct FILETIME *ft)
 {
@@ -192,6 +197,7 @@ convert_timet_to_filetime (time_t t, struct FILETIME *ft)
 	ft->dwLowDateTime = (uint32_t)((nt << 32) >> 32); 
 	ft->dwHighDateTime = (uint32_t)(nt >> 32); 
 }
+#endif
 
 static time_t
 convert_recurrence_minutes_to_timet (uint32_t minutes)
@@ -1070,7 +1076,7 @@ exchange_mapi_cal_util_rrule_to_bin (ECalComponent *comp, GSList *modified_comps
 			flag32 = 0x5AE980DF; 
 		else if (end_type == END_AFTER_N_OCCURRENCES) {
 			ECalComponentDateTime dtstart; 
-			gchar *rrule_str = icalrecurrencetype_as_string (rt); 
+			gchar *rrule_str = icalrecurrencetype_as_string_r (rt); 
 			time_t *array = g_new0 (time_t, rt->count); 
 
 			e_cal_component_get_dtstart (comp, &dtstart);
